==> zio-aws-ecs_2.13-5.17.130.6-sources.jar: zio/aws/ecs/model/TaskDefinitionPlacementConstraint.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class TaskDefinitionPlacementConstraint(
    `type`: Option[zio.aws.ecs.model.TaskDefinitionPlacementConstraintType] =
      None,
    expression: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint = {
    import TaskDefinitionPlacementConstraint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(expression.map(value => value: java.lang.String))(
        _.expression
      )
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.TaskDefinitionPlacementConstraint.ReadOnly =
    zio.aws.ecs.model.TaskDefinitionPlacementConstraint.wrap(buildAwsValue())
}
object TaskDefinitionPlacementConstraint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.TaskDefinitionPlacementConstraint =
      zio.aws.ecs.model.TaskDefinitionPlacementConstraint(
        `type`.map(value => value),
        expression.map(value => value)
      )
    def `type`: Option[zio.aws.ecs.model.TaskDefinitionPlacementConstraintType]
    def expression: Option[String]
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.ecs.model.TaskDefinitionPlacementConstraintType
    ] = AwsError.unwrapOptionField("type", `type`)
    def getExpression: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("expression", expression)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
  ) extends zio.aws.ecs.model.TaskDefinitionPlacementConstraint.ReadOnly {
    override val `type`
        : Option[zio.aws.ecs.model.TaskDefinitionPlacementConstraintType] =
      scala
        .Option(impl.`type`())
        .map(value =>
          zio.aws.ecs.model.TaskDefinitionPlacementConstraintType.wrap(value)
        )
    override val expression: Option[String] =
      scala.Option(impl.expression()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
  ): zio.aws.ecs.model.TaskDefinitionPlacementConstraint.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-ecs_2.13-5.17.194.1-sources.jar: zio/aws/ecs/model/TaskDefinitionPlacementConstraint.scala <==
package zio.aws.ecs.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class TaskDefinitionPlacementConstraint(
    `type`: Optional[zio.aws.ecs.model.TaskDefinitionPlacementConstraintType] =
      Optional.Absent,
    expression: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint = {
    import TaskDefinitionPlacementConstraint.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
      .builder()
      .optionallyWith(`type`.map(value => value.unwrap))(_.`type`)
      .optionallyWith(expression.map(value => value: java.lang.String))(
        _.expression
      )
      .build()
  }
  def asReadOnly: zio.aws.ecs.model.TaskDefinitionPlacementConstraint.ReadOnly =
    zio.aws.ecs.model.TaskDefinitionPlacementConstraint.wrap(buildAwsValue())
}
object TaskDefinitionPlacementConstraint {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ecs.model.TaskDefinitionPlacementConstraint =
      zio.aws.ecs.model.TaskDefinitionPlacementConstraint(
        `type`.map(value => value),
        expression.map(value => value)
      )
    def `type`
        : Optional[zio.aws.ecs.model.TaskDefinitionPlacementConstraintType]
    def expression: Optional[String]
    def getType: ZIO[
      Any,
      AwsError,
      zio.aws.ecs.model.TaskDefinitionPlacementConstraintType
    ] = AwsError.unwrapOptionField("type", `type`)
    def getExpression: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("expression", expression)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
  ) extends zio.aws.ecs.model.TaskDefinitionPlacementConstraint.ReadOnly {
    override val `type`
        : Optional[zio.aws.ecs.model.TaskDefinitionPlacementConstraintType] =
      zio.aws.core.internal
        .optionalFromNullable(impl.`type`())
        .map(value =>
          zio.aws.ecs.model.TaskDefinitionPlacementConstraintType.wrap(value)
        )
    override val expression: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.expression())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ecs.model.TaskDefinitionPlacementConstraint
  ): zio.aws.ecs.model.TaskDefinitionPlacementConstraint.ReadOnly = new Wrapper(
    impl
  )
}
